@@ -143,12 +143,12 @@ def _check_allowed(active_config: GracyConfig, result: httpx.Response) -> bool:
 async def _gracify(
     active_config: GracyConfig,
     endpoint: str,
-    format_args: dict[str, str] | None,
+    endpoint_args: dict[str, str] | None,
     report: GracyReport,
     request: GracefulRequest,
 ):
     if active_config.log_request and isinstance(active_config.log_request, LogEvent):
-        url = endpoint if format_args is None else endpoint.format(**format_args)
+        url = endpoint if endpoint_args is None else endpoint.format(**endpoint_args)
         _process_log_request(active_config.log_request, url)
 
     result = await request()
@@ -175,7 +175,8 @@ async def _gracify(
             if active_config.log_errors and isinstance(active_config.log_errors, LogEvent):
                 _process_log(active_config.log_errors, DefaultLogMessage.ERRORS, result, result.elapsed)
 
-            raise UnexpectedResponse(str(result.url), result, strict_codes)
+            if active_config.retry.behavior == "break":  # type: ignore
+                raise UnexpectedResponse(str(result.url), result, strict_codes)
 
     allowed_pass = _check_allowed(active_config, result)
     if allowed_pass is False:
@@ -195,15 +196,17 @@ async def _gracify(
                 if active_config.log_errors and isinstance(active_config.log_errors, LogEvent):
                     _process_log(active_config.log_errors, DefaultLogMessage.ERRORS, result, result.elapsed)
 
-                raise NonOkResponse(str(result.url), result)
+                if active_config.retry.behavior == "break":  # type: ignore
+                    raise NonOkResponse(str(result.url), result)
 
     if active_config.parser and not isinstance(active_config.parser, Unset):
         default_fallback = active_config.parser.get("default", UNSET_VALUE)
         parse_result = active_config.parser.get(HTTPStatus(result.status_code), default_fallback)
 
         if not isinstance(parse_result, Unset):
-            if isinstance(parse_result, type):
-                raise parse_result()
+            if isinstance(parse_result, type) and issubclass(parse_result, Exception):
+                # if issubclass(parse_result, GracyUserDefinedException):
+                raise parse_result(endpoint, endpoint_args, result)
             elif callable(parse_result):
                 return parse_result(result)
             else:
